/*
 * Copyright (c) 1998-2006 Jitterbit, Inc.
 *
 */
package org.jitterbit.util.collections;

import java.util.ArrayList;
import java.util.Collection;
import java.util.HashSet;

/**
 * Factory for creating <code>java.util.Collection</code> implementations.
 * 
 * @author Torgil
 * 
 * @since 1.2
 *
 */
public interface ICollectionFactory {

    /**
     * Creates a new, empty <code>Collection</code>.
     * 
     */
    public <T> Collection<T> newCollection();
    
    /**
     * Creates a new, empty <code>Collection</code> with the specified initial
     * capacity.
     * 
     */
    public <T> Collection<T> newCollection(int initialCapacity);
    

    /**
     * <code>ICollectionFactory</code> implementation that creates
     * <code>ArrayLists</code>.
     * 
     */
    public static ICollectionFactory    ARRAY_LIST_FACTORY = new ICollectionFactory() {

        public <T> Collection<T> newCollection() {
            return new ArrayList<T>();
        }

        public <T> Collection<T> newCollection(int initialCapacity) {
            return new ArrayList<T>(initialCapacity);
        }
    };
    
    /**
     * <code>ICollectionFactory</code> implementation that creates
     * <code>HashSets</code>.
     * 
     */
    public static ICollectionFactory    HASH_SET_FACTORY = new ICollectionFactory() {

        public <T> Collection<T> newCollection() {
            return new HashSet<T>();
        }

        public <T> Collection<T> newCollection(int initialCapacity) {
            return new HashSet<T>(initialCapacity);
        }
    };
}
