/*
 * Copyright (c) 1998-2006 Jitterbit, Inc.
 *
 */
package org.jitterbit.util.collections;

import java.util.Comparator;

import org.jitterbit.util.lang.KongaObjectUtils;

/**
 * 
 * @author Torgil
 *
 */
public final class Pair<K, V> {

    private final K  m_first;
    private final V  m_second;
    
    public Pair(K first, V second) {
        m_first = first;
        m_second = second;
    }
    
    public K getFirst() {
        return m_first;
    }
    
    public V getSecond() {
        return m_second;
    }

    @Override
    public boolean equals(Object obj) {
        if (obj == this) {
            return true;
        }
        if (obj instanceof Pair) {
            Pair that = (Pair) obj;
            return KongaObjectUtils.areEqual(m_first, that.m_first) &&
                KongaObjectUtils.areEqual(m_second, that.m_second);
        }
        return false;
    }

    @Override
    public int hashCode() {
        int hash = 17;
        hash = 31 * hash + ((m_first == null) ? 0 : m_first.hashCode());
        hash = 31 * hash + ((m_second == null) ? 0 : m_second.hashCode());
        return hash;
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder("[first: ");
        sb.append(m_first);
        sb.append("] [second: ");
        sb.append(m_second);
        sb.append("]");
        return sb.toString();
    }
    
    /**
     * Returns a comparator that will compare Pair instances by using the first
     * element.
     * 
     */
    public static <T extends Comparable<T>, V> Comparator<Pair<T, V>> compareFirst() {
        return new Comparator<Pair<T,V>>() {

            public int compare(Pair<T, V> o1, Pair<T, V> o2) {
                return o1.m_first.compareTo(o2.m_first);
            }
        };
    }

    /**
     * Returns a comparator that will compare Pair instances by using the second
     * element.
     * 
     */
    public static <T, V extends Comparable<V>> Comparator<Pair<T, V>> compareSecond() {
        return new Comparator<Pair<T, V>>() {

            public int compare(Pair<T, V> o1, Pair<T, V> o2) {
                return o1.m_second.compareTo(o2.m_second);
            }
        };
    }
}
