/*
 * Copyright (c) 1998-2005 Jitterbit, Inc.
 *
 */
package org.jitterbit.util.lang;

import java.lang.reflect.Constructor;

/**
 * 
 * @author TorgilZ
 *
 */
public class KongaClassUtils {

	private KongaClassUtils() {
        // No instances of this class.
	}
	
	public static String getClassNameWithoutPackage(Object o) {
		if (o == null) {
			return "";
        }
		return getClassNameWithoutPackage(o.getClass());
	}
	
	public static String getClassNameWithoutPackage(Class cls) {
		if (cls == null) {
			return "";
        }
		
		String sFullName = cls.getName();
		String sPackageName = cls.getPackage().getName();
		return sFullName.substring(sPackageName.length()+1);
	}
	
    /**
     *  
     * @param clazz
     * @param parameterClass
     */
    public static Constructor<?> getSingleArgumentConstructor(Class<?> clazz, 
                                                              Class<?> parameterClass) {
        // TODO: Modify this for the case where more than one constructor exists
        //       that takes one argument that is assignable from parameterClass.
        //       In that case we should return the constructor whose argument is
        //       the closest to parameterClass in the inheritance chain.
        for (Constructor<?> ctor : clazz.getConstructors()) {
            for (Class<?> argClass : ctor.getParameterTypes()) {
                if (argClass.isAssignableFrom(parameterClass)) {
                    return ctor;
                }
            }
        }
        return null;
    }
    
    /**
     * 
     * @param clazz
     */
    public static Constructor<?> getNoArgumentConstuctor(Class<?> clazz) {
        for (Constructor<?> ctor : clazz.getConstructors()) {
            if (ctor.getParameterTypes().length == 0) {
                return ctor;
            }
        }
        return null;
    }
}
